@@ -44,6 +44,8 @@ class Domoticz(IPlugin):
 		idex= entity + "_" + location + "_" + on_off
 		if on_off == "allume" :
 			on_off = "on"
+		if on_off == "eteint" :
+			on_off = "off"
 		log.msg("index :  %s" % (idex))		
 		for rs in self.configuration_plugin['param_dz']:
 #			log.msg("ids  :  %s" % (rs['ids']))
@@ -66,19 +68,11 @@ class Domoticz(IPlugin):
 
 	def devices(self, jsonInput):
 		bodies = ""
-		entity = jsonInput['outcome']['entities']['value']
-		log.msg("entity :  %s" % (entity))		
-		if jsonInput['outcome']['entities']['location']['body'] :
-			location = jsonInput['outcome']['entities']['location']['value']
-		else:
-			bodies = "pas de lieu"
-			location= "VIDE"
-#		if jsonInput['outcome']['entities']['local_search_query']['value'] :
-#			local = jsonInput['outcome']['entities']['local_search_query']['value']
-#		else:
-#			bodies = "pas de local_search_query"
-#
-		idex= location +  "_"
+		entity = jsonInput['outcome']['intent']
+		log.msg("entity :  %s" % (entity))	
+		if entity == "dz_batterie" or "dz_temperature"  :
+			location = jsonInput['outcome']['entities']['location']['body']
+		idex= entity + "_" + location
 		log.msg("idex :  %s" % (idex))		
 #		log.msg("self.configuration_plugin['param_dz']:  %s" % (self.configuration_plugin['param_dz']))		
 		for rs in self.configuration_plugin['param_dz']:
